@@ -16,6 +16,7 @@ get_requires_for_build_sdist = _orig.get_requires_for_build_sdist
 
 cmake_wheels = {
     "win_amd64",
+    "win_arm64",
     "win32",
     "musllinux_1_1_x86_64",
     "musllinux_1_1_s390x",
@@ -27,13 +28,14 @@ cmake_wheels = {
     "manylinux_2_17_aarch64",
     "manylinux_2_17_x86_64",
     "manylinux_2_17_i686",
-    "manylinux_2_5_x86_64",
-    "manylinux_2_5_i686",
+    "manylinux_2_12_x86_64",
+    "manylinux_2_12_i686",
     "macosx_10_10_universal2",
 }
 
 ninja_wheels = {
     "win_amd64",
+    "win_arm64",
     "win32",
     "musllinux_1_1_x86_64",
     "musllinux_1_1_s390x",
@@ -51,7 +53,7 @@ ninja_wheels = {
 
 def _cmake_required():
     try:
-        if _version.parse(_get_cmake_version()) >= _version.parse("3.12"):
+        if _version.parse(_get_cmake_version().split("-")[0]) >= _version.parse("3.12"):
             print("Using System version of cmake")
             return False
     except _SKBuildError:
